@@ -54,6 +54,8 @@ class Programme:
         repr=True,
         compare=False,
     )
+    pvrid: str = "n/a"
+    eid: str = "n/a"
 
     def __hash__(self):
         """Calculate the hash of this object."""
